@@ -143,6 +143,10 @@ class SparkDFUtilsBridge {
     SparkDFUtils.dedupRandomN(df, groupCol, maxSize)
   }
 
+  def dedupByAllExcept(df: DataFrame, ignoredColumn: String): DataFrame = {
+    SparkDFUtils.dedupByAllExcept(df, ignoredColumn, org.apache.spark.sql.functions.max)
+  }
+
   private def convertJavaListToSeq[T](list: JavaList[T]): Seq[T] = {
     scala.collection.JavaConverters
       .asScalaIteratorConverter(list.iterator())
@@ -191,7 +195,7 @@ object SparkDFUtils {
     * the same functionality as {@link #dedupWithOrder} but implemented using UDAF to utilize
     * map side aggregation.
     * this function should be used in cases when you expect a large number of rows to get combined,
-    * as they share the same group column.
+    * as they share the same group column, or if you have some groups with extreme skew.
     *
     * @param df DataFrame to operate on
     * @param groupCol column to group by the records
@@ -245,6 +249,36 @@ object SparkDFUtils {
     df2.sparkSession.createDataFrame(df2.rdd,ns)
   }
 
+/**
+   * Method for reducing rows when there is one column whose value is not important, but you don't want to lose any
+   * actual data from the other rows. For example if a server creates events with an autogenerated event id, and sometimes
+   * events are duplicated. You don't want double rows just for the event ids, but if any of the other fields are distinct
+   * you want to keep the rows (with their event ids)
+   * @param df
+   * @param ignoredColumn The one column whose value you need only one of
+   * @param aggFunction Default is max
+   * @return
+   */
+  def dedupByAllExcept(df: DataFrame, ignoredColumn: String, aggFunction : String => Column): DataFrame = {
+    val cols = df.schema.fields.filter(_.name != ignoredColumn).map(i => i.name)
+    val grouped = df.groupBy(cols.head, cols.tail: _*)
+    val resultWithAggregateFieldName = grouped.agg(aggFunction(ignoredColumn))
+
+    val pattern = s".*\\($ignoredColumn\\)"
+    val candidateFields = resultWithAggregateFieldName.schema.fields.filter(_.name.matches(pattern))
+
+    // Cleanly notify users if something unexpected with the aggregate function name has happened
+    if (candidateFields.isEmpty) {
+      throw new Exception(s"Aggregated field name not found after applying aggregate function to '$ignoredColumn'")
+    } else if (candidateFields.size > 1) {
+      throw new Exception(s"Multiple fields with names that match aggregate function pattern found for '$ignoredColumn'")
+    }
+
+    // rename the aggregated field back to its original name and restore the original order
+    resultWithAggregateFieldName.withColumnRenamed(candidateFields(0).name, ignoredColumn).
+      select(df.columns.head, df.columns.tail:_*)
+  }
+  
   /**
     * Returns a DataFrame with the given column (should be a StructType)
     * replaced by its inner fields.
